3.4. Pre-defined entities in the library — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Repository development »
- 3. Data model »

# 3.4. Pre-defined entities in the library

The library defines a set of entity schemas that are required by the system or commonly used in CubicWeb instances.

## 3.4.1. Entity types used to store the schema

- CWEType, entity type
- CWRType, relation type
- CWRelation, relation definition
- CWAttribute, attribute relation definition
- CWConstraint, CWConstraintType, RQLExpression

## 3.4.2. Entity types used to manage users and permissions

- CWUser, system users
- CWGroup, users groups
- CWPermission, used to configure the security of the instance

## 3.4.3. Entity types used to manage workflows

- Workflow, workflow entity, linked to some entity types which may use this workflow
- State, workflow state
- Transition, workflow transition
- TrInfo, record of a transition trafic for an entity

## 3.4.4. Other entity types

- CWCache, cache entities used to improve performances
- CWProperty, used to configure the instance
- EmailAddress, email address, used by the system to send notifications to the users and also used by others optionnals schemas
- Bookmark, an entity type used to allow a user to customize his links within the instance
- ExternalUri, used for semantic web site to indicate that an entity is the same as another from an external site

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Repository development »
- 3. Data model »